#include "../htmlindex.h"

void head()
{

    cout << "\n"
"<!DOCTYPE html><html><head>\n"
"<title>C++ Annotations HTML Index </title>\n"
"<style> td {vertical-align: top; font-size: 90%; } </style>\n"
"</head>\n"
"<body>\n"
"\n"
"<h1>Index</h1>\n"
"\n"
"<table>\n"
"<tr>\n";
}
