    #include <iostream>
    #include <string>
    using namespace std;

    int main()
    {
        string stringOne("Hello World");

        cout << "The length of the stringOne string is "
            << stringOne.size() << " characters\n";
    }
