#include <iostream>

int main()
{
    int var = 12;
    std::cout << &var << '\n';
    [var]               // lambda expr. using 'var'
    {
        std::cout << &var << '\n';
    }();                // directly call the lambda expr.
}
