#include <iostream>

int main()
{
    struct Date
    {
        int month;
        int day;
    };

    int age = 50;
    int length = 1960;
    Date birthday{3, 13};
    
    std::cout <<
        [
        age = age + 17, // 'age' is a data member of type int,
                             // initialized to 67
        &length,             // 'length' is a data member of type int &,
                             // and refers to the enclosing 'length'
        // birthday.month,   // WC: cannot have a data member '.month'.
        text = "unidentified"
        ]
    {
        return age >= 18 && length > 1400 ? "maybe adult human" : text;
    }() << '\n';

}
