
class NoCopy
{
    int d_number = 12;
public:
    NoCopy(NoCopy const &) = delete;
    int value()
    {
        return[this] // Don't dereference `this`. That requires copying.
        {
            return d_number;
        }();
    }
};

int main()
{
    
}
