void StreamBuf::bufLimits(size_t offset)
{
    bufbeg = offset / blockSize * blockSize;
    bufend = bufbeg + blockSize;

    if (bufend > maxend)        // never exceed maxend
        bufend = maxend;
}
